# `itergame`

`itergame` (previously `iternash`) is an iterative equilibrium finder for simulating arbitrary games in Python/[Coconut](http://coconut-lang.org/). `itergame` is built to make it as easy as possible to simulate and search for equilibria in any multi-agent game.

## Installation

To install `itergame`, just
```
pip install itergame[examples]
```

## Documentation

For information on how to use `itergame`, see:

- [`agent.md`](https://github.com/evhub/iternash/blob/master/docs/itergame/agent.md) for documentation on the various different ways of defining agents,
- [`game.md`](https://github.com/evhub/iternash/blob/master/docs/itergame/game.md) for documentation on creating and simulating a game, and
- [`examples/`](https://github.com/evhub/iternash/tree/master/itergame-source/examples) for examples of `itergame` in action.
